@@ -1,7 +1,13 @@
+"""
+**Persistent cache for Python functions.**
+
+See the documentation for each submodule for detail.
+"""
+
+
 from checkpointing.exceptions import CheckpointNotExist
 from checkpointing.config import defaults
 from checkpointing.decorator import DecoratorCheckpoint, checkpoint
-from checkpointing.identifier import FuncCallIdentifierBase, AutoHashIdentifier
+from checkpointing.identifier import FuncCallIdentifierBase, AutoFuncCallIdentifier
 from checkpointing.cache import CacheBase, PickleFileCache
 from checkpointing._typing import ContextId, ReturnValue
-from checkpointing.hash.specific import register_hasher
