@@ -1,5 +1,5 @@
 from checkpointing.identifier.func_call import (
     FuncCallIdentifierBase,
-    AutoHashIdentifier,
+    AutoFuncCallIdentifier,
     FuncCallContext,
 )
