@@ -1,3 +1,3 @@
 from checkpointing.identifier.func_call.base import FuncCallIdentifierBase
 from checkpointing.identifier.func_call.context import FuncCallContext
-from checkpointing.identifier.func_call.hash import AutoHashIdentifier
+from checkpointing.identifier.func_call.auto import AutoFuncCallIdentifier
