@@ -5,4 +5,4 @@ logger = logging.getLogger("checkpointing")
 Logger used by all components of the checkpointing module.
 """
 
-logger.setLevel(logging.FATAL)
+logger.setLevel(logging.CRITICAL)
